@@ -1,7 +1,7 @@
 #!/usr/bin/python2.5
-# versione 1.2
+# versione 1.4
 # ui di configurazione per savepu
-# by m750 at maemomeego.net
+# by m750 at smartphonetab.net
 
 import sys
 import osso
@@ -13,8 +13,8 @@ from PyQt4.QtCore import *
 from savecpu_ui import *
 
 
-Global_Version = '2.18.12-1'
-UI_Version = '1.2'
+Global_Version = '2.20.14-1'
+UI_Version = '1.4'
 
 try:
     _fromUtf8 = QtCore.QString.fromUtf8
@@ -40,16 +40,16 @@ class About(QtGui.QMainWindow):
         aboutLayout = QVBoxLayout(awidget)
 
         aboutLabel = QLabel('''<center><b>savecpu</b> %s
-               <br>Application for N900 with Titan's kernel and active overclock.
-               <br>It works in the background, watching the temperature through the
-               <br><b>bq27200</b> module.
+               <br>Application for N900 with Titan's/Pali's kernel and active overclock.
+               <br>It works in background, watching the temperature (no more through the
+               <br><b>bq27200</b> module).
                <br>
                <br></center>With this interface it's possible to set:
                <br> - LED colors
                <br> - activation temperature
                <br> - control delay
                <br> - enable/disable check
-               <br><center>by <b>Marco (m750 at mamemomeego.net)</b>
+               <br><center>by <b>Marco (m750 at smartphonetab)</b>
                <br></center>''' % Global_Version )
         aboutLayout.addWidget(aboutLabel)
         
@@ -186,13 +186,15 @@ class MyForm(QtGui.QMainWindow):
                 global colore_r , colore_g , colore_b, enable, temperatura, check_v
 
                 time.sleep(0.1)
-                temperatura = os.popen('cat /sys/class/power_supply/bq27200-0/temp').read()
-
+                #temperatura = os.popen('cat /sys/class/power_supply/bq27200-0/temp').read()
+                temperatura = os.popen('cat /sys/devices/platform/omap34xx_temp/temp1_input').read()
                 # kernel v47
-                temperatura=temperatura.strip()
+                #temperatura=temperatura.strip()
                 #print temperatura
-                if len(temperatura) == 3 :
-                    temperatura = int(temperatura) / 10
+                #if len(temperatura) == 3 :
+                #    temperatura = int(temperatura) / 10
+                temperatura = int(temperatura) + 10
+
                 temperatura=str(temperatura)    
                 #print temperatura
 
